%global pkgconfdir      %{_sysconfdir}/dpkg
%global pkgdatadir      %{_datadir}/dpkg

Summary:        Package maintenance system for Debian Linux
Name:           dpkg
Version:        1.21.22
Release:        1%{?dist}
License:        GPLv2 and GPLv2+ and LGPLv2+ and Public Domain and BSD
URL:            https://tracker.debian.org/pkg/dpkg
Source0:        http://ftp.debian.org/debian/pool/main/d/dpkg/%{name}_%{version}.tar.xz
Patch3000:      cputable_ppc64le.patch

BuildRequires: autoconf, automake, gcc-c++, gettext, gettext-devel, make, libtool
BuildRequires: bzip2-devel, doxygen, dotconf-devel, libmd-devel, libselinux-devel, libzstd-devel
BuildRequires: po4a >= 0.59, xz-devel, zlib-devel, ncurses-devel
BuildRequires: perl-interpreter, perl-generators, perl-Time-Piece, perl-podlators, perl-Digest, perl-devel >= 5.28.1
# Need by make check
BuildRequires: perl-Test-Simple, perl-IPC-Cmd, perl-Digest-MD5, perl-Digest-SHA, perl-IO-String, perl-Tie
BuildRequires: fakeroot

Requires:      tar >= 1.28
Requires(post): coreutils

%global __requires_exclude %{?__requires_exclude:%{__requires_exclude}|}^perl\\(at|extra|file\\)$

%description
This package provides the low-level infrastructure for handling the
installation and removal of Debian software packages.

This package contains the tools (including dpkg-source) required
to install, remove, unpack, build and upload Debian source packages.

%package devel
Summary: Debian package management static library
Provides: dpkg-static = %{version}-%{release}

%description devel
This package provides the header files and static library necessary to
develop software using dpkg, the same library used internally by dpkg.

%package dev
Summary:  Debian package development tools
Requires: dpkg-perl = %{version}-%{release}
Requires: patch
Requires: make
Requires: binutils
Requires: bzip2
Requires: lzma
Requires: xz
Requires: zstd
Requires:  gcc
BuildArch: noarch

%description dev
This package provides the development tools (including dpkg-source)
required to unpack, build and upload Debian source packages.

%package perl
Summary: Dpkg perl modules
Requires: dpkg = %{version}-%{release}
Requires: perl-TimeDate
Requires: perl-Time-Piece
Requires: perl(Digest::MD5)
Requires: perl(Digest::SHA)
Requires: perl(Digest::SHA1)
BuildArch: noarch

%description perl
This package provides the perl modules used by the scripts
in dpkg-dev. They cover a wide range of functionality.

%package -n dselect
Summary:  Debian package management front-end
Requires: %{name} = %{version}-%{release}

%description -n dselect
dselect is a high-level interface for managing the installation and
removal of Debian software packages.



%prep
%autosetup -p1

%build
autoreconf
%configure --disable-linker-optimisations \
        --with-admindir=%{_localstatedir}/lib/dpkg \
        --runstatedir=/run \
        --with-libselinux \
        --with-libz \
        --with-liblzma \
        --with-libzstd \
        --with-libbz2

%make_build



%install
%make_install

mkdir -p %{buildroot}/%{pkgconfdir}/origins

cat <<EOF > %{buildroot}/%{pkgconfdir}/origins/%{_vendor}
Vendor: %{_vendor}
EOF

ln -sf %{_vendor} %{buildroot}/%{pkgconfdir}/origins/default

install -pm0644 debian/dpkg.cfg %{buildroot}/%{pkgconfdir}
install -pm0644 debian/dselect.cfg %{buildroot}/%{pkgconfdir}
install -pm0644 debian/shlibs.default %{buildroot}/%{pkgconfdir}
install -pm0644 debian/shlibs.override %{buildroot}/%{pkgconfdir}

mkdir -p %{buildroot}/%{_sysconfdir}/logrotate.d
install -pm0644 debian/dpkg.logrotate %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}

admindir=${DPKG_ADMINDIR:-%{buildroot}%{_localstatedir}/lib/dpkg}

for file in diversions statoverride status; do
if [ ! -f "$admindir/$file" ]; then
    touch "$admindir/$file"
fi
done

logfile=%{buildroot}%{_localstatedir}/log/dpkg.log
mkdir -p %{buildroot}%{_localstatedir}/log/
touch $logfile
chmod 644 $logfile

rm %{buildroot}%{_libdir}/libdpkg.la

rm %{buildroot}%{_bindir}/update-alternatives
rm %{buildroot}%{_mandir}/man1/update-alternatives.1
rm -r %{buildroot}%{_mandir}/*/man1/update-alternatives.1
rm -r %{buildroot}%{_sysconfdir}/alternatives/

%find_lang dpkg
%find_lang dpkg-dev
%find_lang dselect



%check
make VERBOSE=1 TESTSUITEFLAGS=--verbose \
    TEST_PARALLEL=4 check || :



%files -f dpkg.lang
%license debian/copyright
%doc debian/changelog README AUTHORS THANKS TODO
%doc debian/README.bug-usertags debian/dpkg.cron.daily
%dir %{pkgconfdir}
%dir %{pkgconfdir}/dpkg.cfg.d
%dir %{pkgconfdir}/origins
%config(noreplace) %{pkgconfdir}/dpkg.cfg
%config(noreplace) %{pkgconfdir}/origins/*
%config(noreplace) %{_sysconfdir}/logrotate.d/dpkg
%dir %{_localstatedir}/lib/dpkg
%config(noreplace) %{_localstatedir}/log/%{name}.log
%config(noreplace) %{_localstatedir}/lib/dpkg/diversions
%config(noreplace) %{_localstatedir}/lib/dpkg/statoverride
%config(noreplace) %{_localstatedir}/lib/dpkg/status
%{_bindir}/dpkg
%{_bindir}/dpkg-deb
%{_bindir}/dpkg-maintscript-helper
%{_bindir}/dpkg-query
%{_bindir}/dpkg-split
%{_bindir}/dpkg-trigger
%{_bindir}/dpkg-divert
%{_bindir}/dpkg-statoverride
%{_bindir}/dpkg-realpath
%{_sbindir}/start-stop-daemon
%{_sbindir}/dpkg-fsys-usrunmess
%{_libexecdir}/dpkg/dpkg-db-backup
%dir %{pkgdatadir}
%{pkgdatadir}/abitable
%{pkgdatadir}/cputable
%{pkgdatadir}/ostable
%{pkgdatadir}/tupletable
%{_mandir}/man1/dpkg.1.gz
%{_mandir}/man1/dpkg-deb.1.gz
%{_mandir}/man1/dpkg-maintscript-helper.1.gz
%{_mandir}/man1/dpkg-query.1.gz
%{_mandir}/man1/dpkg-split.1.gz
%{_mandir}/man1/dpkg-trigger.1.gz
%{_mandir}/man5/dpkg.cfg.5.gz
%{_mandir}/man1/dpkg-divert.1.gz
%{_mandir}/man1/dpkg-statoverride.1.gz
%{_mandir}/man8/start-stop-daemon.8.gz
%{_mandir}/man1/dpkg-realpath.1.gz
%{_mandir}/man8/dpkg-fsys-usrunmess.8.gz
%{_mandir}/*/man1/dpkg.1.gz
%{_mandir}/*/man1/dpkg-deb.1.gz
%{_mandir}/*/man1/dpkg-maintscript-helper.1.gz
%{_mandir}/*/man1/dpkg-query.1.gz
%{_mandir}/*/man1/dpkg-split.1.gz
%{_mandir}/*/man1/dpkg-trigger.1.gz
%{_mandir}/*/man5/dpkg.cfg.5.gz
%{_mandir}/*/man1/dpkg-divert.1.gz
%{_mandir}/*/man1/dpkg-statoverride.1.gz
%{_mandir}/*/man8/start-stop-daemon.8.gz
%{_mandir}/*/man1/dpkg-realpath.1.gz
%{_mandir}/*/man8/dpkg-fsys-usrunmess.8.gz
%{_datadir}/polkit-1/actions/org.dpkg.pkexec.update-alternatives.policy
%{_datadir}/doc/dpkg/*
%{_datadir}/dpkg/sh/dpkg-error.sh

%files devel
%{_libdir}/libdpkg.a
%{_libdir}/pkgconfig/libdpkg.pc
%{_includedir}/dpkg/*.h
%{_datadir}/aclocal/dpkg-*.m4

%files dev -f dpkg-dev.lang
%doc doc/README.feature-removal-schedule doc/README.api doc/spec
%config(noreplace) %{pkgconfdir}/shlibs.default
%config(noreplace) %{pkgconfdir}/shlibs.override
%{_bindir}/dpkg-architecture
%{_bindir}/dpkg-buildpackage
%{_bindir}/dpkg-buildflags
%{_bindir}/dpkg-checkbuilddeps
%{_bindir}/dpkg-distaddfile
%{_bindir}/dpkg-genbuildinfo
%{_bindir}/dpkg-genchanges
%{_bindir}/dpkg-gencontrol
%{_bindir}/dpkg-gensymbols
%{_bindir}/dpkg-mergechangelogs
%{_bindir}/dpkg-name
%{_bindir}/dpkg-parsechangelog
%{_bindir}/dpkg-scanpackages
%{_bindir}/dpkg-scansources
%{_bindir}/dpkg-shlibdeps
%{_bindir}/dpkg-source
%{_bindir}/dpkg-vendor
%{pkgdatadir}/*.mk
%{_datadir}/zsh/vendor-completions/_dpkg-parsechangelog
%{_mandir}/man5/deb-buildinfo.5.gz
%{_mandir}/man5/deb-changelog.5.gz
%{_mandir}/man5/deb-changes.5.gz
%{_mandir}/man5/deb-conffiles.5.gz
%{_mandir}/man5/deb-control.5.gz
%{_mandir}/man5/deb-extra-override.5.gz
%{_mandir}/man5/deb-md5sums.5.gz
%{_mandir}/man5/deb-old.5.gz
%{_mandir}/man5/deb-origin.5.gz
%{_mandir}/man5/deb-override.5.gz
%{_mandir}/man5/deb-postinst.5.gz
%{_mandir}/man5/deb-postrm.5.gz
%{_mandir}/man5/deb-preinst.5.gz
%{_mandir}/man5/deb-prerm.5.gz
%{_mandir}/man5/deb-shlibs.5.gz
%{_mandir}/man5/deb-split.5.gz
%{_mandir}/man5/deb-src-control.5.gz
%{_mandir}/man5/deb-src-files.5.gz
%{_mandir}/man5/deb-src-rules.5.gz
%{_mandir}/man5/deb-src-symbols.5.gz
%{_mandir}/man5/deb-substvars.5.gz
%{_mandir}/man5/deb-symbols.5.gz
%{_mandir}/man5/deb-triggers.5.gz
%{_mandir}/man7/deb-version.7.gz
%{_mandir}/man5/deb.5.gz
%{_mandir}/man5/deb822.5.gz
%{_mandir}/man1/dpkg-architecture.1.gz
%{_mandir}/man1/dpkg-buildflags.1.gz
%{_mandir}/man1/dpkg-buildpackage.1.gz
%{_mandir}/man1/dpkg-checkbuilddeps.1.gz
%{_mandir}/man1/dpkg-distaddfile.1.gz
%{_mandir}/man1/dpkg-genbuildinfo.1.gz
%{_mandir}/man1/dpkg-genchanges.1.gz
%{_mandir}/man1/dpkg-gencontrol.1.gz
%{_mandir}/man1/dpkg-gensymbols.1.gz
%{_mandir}/man1/dpkg-mergechangelogs.1.gz
%{_mandir}/man1/dpkg-name.1.gz
%{_mandir}/man1/dpkg-parsechangelog.1.gz
%{_mandir}/man1/dpkg-scanpackages.1.gz
%{_mandir}/man1/dpkg-scansources.1.gz
%{_mandir}/man1/dpkg-shlibdeps.1.gz
%{_mandir}/man1/dpkg-source.1.gz
%{_mandir}/man1/dpkg-vendor.1.gz
%{_mandir}/man5/dsc.5.gz
%{_mandir}/*/man5/deb-buildinfo.5.gz
%{_mandir}/*/man5/deb-changelog.5.gz
%{_mandir}/*/man5/deb-changes.5.gz
%{_mandir}/*/man5/deb-conffiles.5.gz
%{_mandir}/*/man5/deb-control.5.gz
%{_mandir}/*/man5/deb-extra-override.5.gz
%{_mandir}/*/man5/deb-md5sums.5.gz
%{_mandir}/*/man5/deb-old.5.gz
%{_mandir}/*/man5/deb-origin.5.gz
%{_mandir}/*/man5/deb-override.5.gz
%{_mandir}/*/man5/deb-postinst.5.gz
%{_mandir}/*/man5/deb-postrm.5.gz
%{_mandir}/*/man5/deb-preinst.5.gz
%{_mandir}/*/man5/deb-prerm.5.gz
%{_mandir}/*/man5/deb-shlibs.5.gz
%{_mandir}/*/man5/deb-split.5.gz
%{_mandir}/*/man5/deb-src-control.5.gz
%{_mandir}/*/man5/deb-src-files.5.gz
%{_mandir}/*/man5/deb-src-rules.5.gz
%{_mandir}/*/man5/deb-src-symbols.5.gz
%{_mandir}/*/man5/deb-substvars.5.gz
%{_mandir}/*/man5/deb-symbols.5.gz
%{_mandir}/*/man5/deb-triggers.5.gz
%{_mandir}/*/man7/deb-version.7.gz
%{_mandir}/*/man5/deb.5.gz
%{_mandir}/*/man5/deb822.5.gz
%{_mandir}/*/man1/dpkg-architecture.1.gz
%{_mandir}/*/man1/dpkg-buildflags.1.gz
%{_mandir}/*/man1/dpkg-buildpackage.1.gz
%{_mandir}/*/man1/dpkg-checkbuilddeps.1.gz
%{_mandir}/*/man1/dpkg-distaddfile.1.gz
%{_mandir}/*/man1/dpkg-genbuildinfo.1.gz
%{_mandir}/*/man1/dpkg-genchanges.1.gz
%{_mandir}/*/man1/dpkg-gencontrol.1.gz
%{_mandir}/*/man1/dpkg-gensymbols.1.gz
%{_mandir}/*/man1/dpkg-mergechangelogs.1.gz
%{_mandir}/*/man1/dpkg-name.1.gz
%{_mandir}/*/man1/dpkg-parsechangelog.1.gz
%{_mandir}/*/man1/dpkg-scanpackages.1.gz
%{_mandir}/*/man1/dpkg-scansources.1.gz
%{_mandir}/*/man1/dpkg-shlibdeps.1.gz
%{_mandir}/*/man1/dpkg-source.1.gz
%{_mandir}/*/man1/dpkg-vendor.1.gz
%{_mandir}/*/man5/dsc.5.gz

%files perl
%{perl_vendorlib}/Dpkg*
%{_mandir}/man3/Dpkg*.3*
%{_datadir}/dpkg/*.specs

%files -n dselect -f dselect.lang
%{_bindir}/dselect
%config(noreplace) %{pkgconfdir}/dselect.cfg
%dir %{pkgconfdir}/dselect.cfg.d
%{perl_vendorlib}/Dselect
%{_localstatedir}/lib/dpkg/methods
%{_libexecdir}/dpkg/methods
%{_mandir}/man1/dselect.1.gz
%{_mandir}/*/man1/dselect.1.gz
%{_mandir}/man5/dselect.cfg.5.gz
%{_mandir}/*/man5/dselect.cfg.5.gz



%changelog
* Fri Oct 27 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.21.22-1
- initial
